!+
! Module: temp_ssclib
!
! Authors:  Ian Stewart - SSC/LUX
!          
! Description: Contains routines shared between rgssources and rgssources_update.
! 
! $Id: rgssources_shared.f90,v 1.2 2000/08/11 13:08:45 pvideler Exp $
!- 
module temp_ssclib

! You should write the module name in the 'use' statement, the package name
! (and version number) in the DEPEND file, and the * from the lib*.a name in
! <package>/src/Makefile.
!  use dal
!  use cal
!  use errorHandling
!  use oal
!  use constants
!  use rgssources_init
!  use temp_rgslib
!  use pointing_mod

  implicit none 

  private

  public ucase				!***** put this in ssclib!
  public stringDump			!***** put this in ssclib!
  public no0s				!***** put this in ssclib!
  public strToInteger			!***** put this in ssclib!
  public intToStr			!***** put this in ssclib!

contains 

  !---------------------------------------------------------------------
  function ucase(arg) result(string)
  !---------------------------------------------------------------------

    implicit none 

    character(*), intent(in) :: arg
    character(len=len(arg)) :: string
    integer :: i, asciiIndex, aAsciiIndex, zAsciiIndex, bigAasciiIndex

    !-------------------------------------------------------------------
    ! Start:

    aAsciiIndex = ichar('a')
    zAsciiIndex = ichar('z')
    bigAasciiIndex = ichar('A')
    string = arg
    do i = 1, len(arg)
      asciiIndex = ichar(string(i:i))
      if (asciiIndex .ge. aAsciiIndex .and. asciiIndex .le. zAsciiIndex) then
        string(i:i) = char(bigAasciiIndex + asciiIndex - aAsciiIndex)
      end if
    end do

  end function ucase

  !---------------------------------------------------------------------
  subroutine stringDump(str)
  !---------------------------------------------------------------------

    implicit none 

    character(*), intent(in) :: str

    character(1) :: chr
    integer :: length, i, index

    !-------------------------------------------------------------------
    ! Start:

    length = len(str)

    if (length .le. 0) then
      print *, 'There are 0 characters in the string.'
  return

    else if (length .eq. 1) then
      print *, 'There is 1 character in the string.'

    else
      print *, 'There are', length, 'characters in the string.'
    end if
    print *, ''

    do i = 1, length
      chr = str(i:i)
      index = ichar(chr)
      if (index .le. 32 .or. index .ge. 127) then
        chr = ' '
      end if
      write(*, '(a3, z2)') chr//'  ', index
    end do

  end subroutine stringDump

  !---------------------------------------------------------------------
  function no0s(str)
  !---------------------------------------------------------------------

    implicit none 

    character(*), intent(in) :: str

    character(len=len(str)) :: no0s, tempstr
    character(1) :: chr
    integer :: length, i, index, lastChar

    !-------------------------------------------------------------------
    ! Start:

    length = len(str)
    if (length .le. 0) then
      no0s = str
  return
    end if

    lastChar = length
    do i = length, 1, -1
      chr = str(i:i)
      index = ichar(chr)
      if (index .ne. 0 .and. index .ne. ichar(' ')) then
        lastChar = i
    exit
      end if
      tempstr(i:i) = ' '
    end do
    tempstr(1:lastChar) = str(1:lastChar)

no0s = tempstr

  end function no0s

  !---------------------------------------------------------------------
  subroutine strToInteger(str, int, status)
  !---------------------------------------------------------------------

    implicit none 

    character(*), intent(in) :: str
    integer, intent(out) :: int, status

    integer :: i, length, nonZeroLength, mult

    !-------------------------------------------------------------------
    ! Start:

    status = 0 ! default
    int    = 0 ! default

    length = len(str)
    if (length .le. 0) then
      status = 1
  return
    end if

    do i = 1, length
      if (iachar(str(i:i)) .lt. iachar('0')&
      .or. iachar(str(i:i)) .gt. iachar('9')) then
        status = 2
  return
      end if
    end do

    nonZeroLength = 0
    do i = 1, length
      if (iachar(str(i:i)) .ne. iachar('0')) then
        nonZeroLength = length + 1 - i
      end if
    end do

    if (nonZeroLength .eq. 0) then
      int = 0
  return
    end if

    if (nonZeroLength .gt. floor(log10(real(huge(int))))) then
    ! floor because eg huge(int16) is 32768, thus ceiling(log10(huge(int16)))
    ! is 5, allowing a str value of, for example, '32769', which would cause
    ! an overflow.
      status = 3
  return
    end if

    int = iachar(str(length:length)) - iachar('0')
    mult = 1
    do i = length - 1, 1 + length - nonZeroLength, -1
      mult = mult * 10
      int = int + mult * iachar(str(i:i)) - iachar('0')
    end do

  end subroutine strToInteger

  !---------------------------------------------------------------------
  subroutine intToStr(int, justify, str, status)
  !---------------------------------------------------------------------

    implicit none

    integer,      intent(in)  :: int
    character(*), intent(in)  :: justify
    character(*), intent(out) :: str
    integer,      intent(out) :: status

    integer :: numCharRequired

    !-------------------------------------------------------------------
    ! Start

    status = 0 ! default
    str = '' ! default

    numCharRequired = 1 + log10(real(int))
    if (int .lt. 0) numCharRequired = numCharRequired + 1
    if (numCharRequired .gt. len(str)) then
      status = -1
  return
    end if

    write(str, *) int
    if (justify .eq. 'left') then
      str = adjustl(str)
    else
      str = adjustr(str)
    end if

  end subroutine intToStr

  !---------------------------------------------------------------------
  subroutine template
  !---------------------------------------------------------------------

    implicit none

    !-------------------------------------------------------------------
    ! Start

  end subroutine template
end module temp_ssclib






